﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Timelines;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private Canvas _sceneCanvas;
        private Rectangle _marker;
        private DateTimeAxis _axis;

        public MainWindow()
        {
            InitializeComponent();
        }

        private void xamTimeline1_Loaded(object sender, RoutedEventArgs e)
        {
            _axis = xamTimeline1.Axis as DateTimeAxis;
            if (_axis == null)
                return;

            _sceneCanvas = (Canvas)Infragistics.Windows.Utilities.GetDescendantFromName(xamTimeline1, "SceneCanvas");
            if (_sceneCanvas != null)
            {
                _marker = new Rectangle() { Width = 1.0, Fill = Brushes.Red, };
                Binding b = new Binding("ActualHeight") { Source = _sceneCanvas };
                BindingOperations.SetBinding(_marker, Rectangle.HeightProperty, b);
                _sceneCanvas.Children.Add(_marker);
            }

            if (_axis != null)
                UpdateMarker(_sceneCanvas.ActualWidth, _axis.VisibleMinimum, _axis.VisibleMaximum, DateTime.Now);
            
            xamTimeline1.Zoombar.ZoomChanged += Zoombar_ZoomChanged;
            xamTimeline1.SizeChanged += xamTimeline1_SizeChanged;
        }

        void xamTimeline1_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            if (_axis != null)
                UpdateMarker(_sceneCanvas.ActualWidth, _axis.VisibleMinimum, _axis.VisibleMaximum, DateTime.Now);
        }

        void Zoombar_ZoomChanged(object sender, Infragistics.Controls.ZoomChangedEventArgs e)
        {
            if (_axis != null)
                UpdateMarker(_sceneCanvas.ActualWidth, _axis.VisibleMinimum, _axis.VisibleMaximum, DateTime.Now);
        }

        private void UpdateMarker(double width, DateTime minimum, DateTime maximum, DateTime position)
        {
            double minimumTicks = (double)minimum.Ticks;
            double maximumTicks = (double)maximum.Ticks;
            double positionTicks = (double)position.Ticks;

            // hide the marker if it is out of view.
            if (positionTicks < minimumTicks || positionTicks > maximumTicks)
                _marker.Visibility = System.Windows.Visibility.Collapsed;
            else
                _marker.Visibility = System.Windows.Visibility.Visible;

            double percent = (positionTicks - minimumTicks) / (maximumTicks - minimumTicks);
            double pixel = width * percent;
            Canvas.SetLeft(_marker, pixel);
        }
    }
}
